@@ -27,7 +27,6 @@
 #include <collectionfetchjob.h>
 #include <collectionfetchscope.h>
 #include <collectionmodifyjob.h>
-#include <itemdeletejob.h>
 #include <itemmodifyjob.h>
 #include <KCheckableProxyModel>
 #include <KEMailSettings>
@@ -40,7 +39,6 @@ using namespace KCalCore;
 
 Q_DECLARE_METATYPE(QSet<QByteArray>)
 
-
 KCalCore::Incidence::Ptr Akonadi::CalendarUtils::incidence(const Akonadi::Item &item)
 {
     // With this try-catch block, we get a 2x performance improvement in retrieving the payload
@@ -58,7 +56,7 @@ void ETMCalendarTest::createIncidence(const QString &uid)
     item.setMimeType(Event::eventMimeType());
     Incidence::Ptr incidence = Incidence::Ptr(new Event());
     incidence->setUid(uid);
-    incidence->setDtStart(KDateTime::currentDateTime(KDateTime::UTC));
+    incidence->setDtStart(QDateTime::currentDateTimeUtc());
     incidence->setSummary(QStringLiteral("summary"));
     item.setPayload<KCalCore::Incidence::Ptr>(incidence);
     ItemCreateJob *job = new ItemCreateJob(item, mCollection, this);
@@ -262,7 +260,6 @@ void ETMCalendarTest::testSelectCollection()
     }
 }
 
-
 void ETMCalendarTest::calendarIncidenceAdded(const Incidence::Ptr &incidence)
 {
     Q_ASSERT(incidence);
@@ -307,7 +304,7 @@ void ETMCalendarTest::calendarIncidenceChanged(const Incidence::Ptr &incidence)
     checkExitLoop();
 }
 
-void ETMCalendarTest::calendarIncidenceDeleted(const Incidence::Ptr &incidence, const KCalCore::Calendar* cal)
+void ETMCalendarTest::calendarIncidenceDeleted(const Incidence::Ptr &incidence, const KCalCore::Calendar *cal)
 {
     Q_UNUSED(cal);
     const QString id = incidence->customProperty("VOLATILE", "AKONADI-ID");
@@ -427,7 +424,7 @@ void ETMCalendarTest::testNotifyObserverBug()
     // and that observer then called calendar->item(incidence->uid()) the retrieved item would still
     // have the old payload, because CalendarBase::updateItem() was still on the stack
     // and would only update after calendarIncidenceChanged() returned.
-    // This test ensure that doesnt happen.
+    // This test ensure that doesn't happen.
     const QLatin1String uid("todo-notify-bug");
     createTodo(uid, QString());
     waitForIt();
@@ -510,7 +507,6 @@ void ETMCalendarTest::testItem()
     // The pointers should be the same
     QCOMPARE(incidence1.data(), incidence2.data());
     QCOMPARE(incidence.data(), incidence1.data());
-
 }
 
 void ETMCalendarTest::testShareETM()
@@ -545,7 +541,7 @@ void ETMCalendarTest::testFilterInvitations()
 
     item.setMimeType(Event::eventMimeType());
     incidence->setUid(uid);
-    incidence->setDtStart(KDateTime::currentDateTime(KDateTime::UTC));
+    incidence->setDtStart(QDateTime::currentDateTimeUtc());
     incidence->setSummary(QStringLiteral("summary"));
 
     me->setStatus(KCalCore::Attendee::NeedsAction);
@@ -582,7 +578,7 @@ void ETMCalendarTest::testFilterInvitationsChanged()
     item.setPayload<KCalCore::Incidence::Ptr>(incidence);
 
     mIncidencesToDelete = 1;
-    ItemModifyJob *modifyJob = new ItemModifyJob(item,  this);
+    ItemModifyJob *modifyJob = new ItemModifyJob(item, this);
     AKVERIFYEXEC(modifyJob);
     waitForIt();
     QCOMPARE(mCalendar->model()->rowCount(), anz);
@@ -596,13 +592,12 @@ void ETMCalendarTest::testFilterInvitationsChanged()
     item.setPayload<KCalCore::Incidence::Ptr>(incidence);
     item.setRevision(2);
     mIncidencesToAdd = 1;
-    modifyJob = new ItemModifyJob(item,  this);
+    modifyJob = new ItemModifyJob(item, this);
     AKVERIFYEXEC(modifyJob);
     waitForIt();
     QCOMPARE(mCalendar->model()->rowCount(), anz+1);
 }
 
-
 void ETMCalendarTest::waitForIt()
 {
     QTestEventLoop::instance().enterLoop(10);
