@@ -42,7 +42,7 @@ public:
     void setFilter(KCalCore::CalFilter *filter);
 
 protected:
-    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const Q_DECL_OVERRIDE;
+    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
 
 private:
     class Private;
