@@ -40,7 +40,6 @@
 #include <QUrl>
 #include <KIO/Job>
 #include <KIO/JobUiDelegate>
-#include <KIO/NetAccess>
 #include <KLocalizedString>
 
 #include <QDir>
@@ -152,7 +151,7 @@ FreeBusyManagerPrivate::FreeBusyProvidersRequestsQueue::FreeBusyProvidersRequest
     // Set the start of the period to today 00:00:00
     mStartTime = QDateTime(QDate::currentDate(), QTime());
     mEndTime = mStartTime.addDays(14);
-    mResultingFreeBusy = KCalCore::FreeBusy::Ptr(new KCalCore::FreeBusy(KDateTime(mStartTime), KDateTime(mEndTime)));
+    mResultingFreeBusy = KCalCore::FreeBusy::Ptr(new KCalCore::FreeBusy(mStartTime, mEndTime));
 }
 
 FreeBusyManagerPrivate::FreeBusyProvidersRequestsQueue::FreeBusyProvidersRequestsQueue(
@@ -161,7 +160,7 @@ FreeBusyManagerPrivate::FreeBusyProvidersRequestsQueue::FreeBusyProvidersRequest
 {
     mStartTime = start;
     mEndTime = end;
-    mResultingFreeBusy = KCalCore::FreeBusy::Ptr(new KCalCore::FreeBusy(KDateTime(start), KDateTime(end)));
+    mResultingFreeBusy = KCalCore::FreeBusy::Ptr(new KCalCore::FreeBusy(start, end));
 }
 
 /// FreeBusyManagerPrivate
@@ -372,8 +371,8 @@ KCalCore::FreeBusy::Ptr FreeBusyManagerPrivate::iCalToFreeBusy(const QByteArray
 
 KCalCore::FreeBusy::Ptr FreeBusyManagerPrivate::ownerFreeBusy()
 {
-    KDateTime start = KDateTime::currentUtcDateTime();
-    KDateTime end = start.addDays(CalendarSettings::self()->freeBusyPublishDays());
+    QDateTime start = QDateTime::currentDateTimeUtc();
+    QDateTime end = start.addDays(CalendarSettings::self()->freeBusyPublishDays());
 
     KCalCore::Event::List events = mCalendar ? mCalendar->rawEvents(start.date(), end.date()) : KCalCore::Event::List();
     KCalCore::FreeBusy::Ptr freebusy(new KCalCore::FreeBusy(events, start, end));
@@ -497,7 +496,7 @@ void FreeBusyManagerPrivate::finishProcessRetrieveQueue(const QString &email,
     mFreeBusyUrlEmailMap.insert(freeBusyUrlForEmail, email);
 
     FreeBusyDownloadJob *job = new FreeBusyDownloadJob(freeBusyUrlForEmail, mParentWidgetForRetrieval);
-    q->connect(job, SIGNAL(result(KJob*)), SLOT(processFreeBusyDownloadResult(KJob*)));
+    q->connect(job, &FreeBusyDownloadJob::result, this, [this](KJob*job) { processFreeBusyDownloadResult(job);});
     job->start();
 }
 
@@ -756,7 +755,7 @@ void FreeBusyManager::setCalendar(const Akonadi::ETMCalendar::Ptr &c)
 
     d->mCalendar = c;
     if (d->mCalendar) {
-        d->mFormat.setTimeSpec(d->mCalendar->timeSpec());
+        d->mFormat.setTimeZone(d->mCalendar->timeZone());
         connect(d->mCalendar.data(), SIGNAL(calendarChanged()), SLOT(uploadFreeBusy()));
     }
 
@@ -898,8 +897,8 @@ void FreeBusyManager::mailFreeBusy(int daysToPublish, QWidget *parentWidget)
         return;
     }
 
-    KDateTime start = KDateTime::currentUtcDateTime().toTimeSpec(d->mCalendar->timeSpec());
-    KDateTime end = start.addDays(daysToPublish);
+    QDateTime start = QDateTime::currentDateTimeUtc().toTimeZone(d->mCalendar->timeZone());
+    QDateTime end = start.addDays(daysToPublish);
 
     KCalCore::Event::List events = d->mCalendar->rawEvents(start.date(), end.date());
 
