@@ -52,12 +52,12 @@ public:
       @see KCalPrefBase::freeBusyPublishUrl()
       @see KCalPrefBase::freeBusyPublishDays();
       */
-    void publishFreeBusy(QWidget *parentWidget = Q_NULLPTR);
+    void publishFreeBusy(QWidget *parentWidget = nullptr);
 
     /**
       Mail the freebusy information.
       */
-    void mailFreeBusy(int daysToPublish = 30, QWidget *parentWidget = Q_NULLPTR);
+    void mailFreeBusy(int daysToPublish = 30, QWidget *parentWidget = nullptr);
 
     /**
       Retrieve the freebusy information of somebody else, i.e. it will not try
@@ -93,24 +93,7 @@ public:
       @return true if a download is initiated, and false otherwise
     */
     bool retrieveFreeBusy(const QString &email, bool forceDownload,
-                          QWidget *parentWidget = Q_NULLPTR);
-
-    /**
-        Retrieve the freebusy information of a contact for a specified period.
-
-        This method works as the previous one except that there is no fallback
-        on the URL mechanism.
-
-        @param email Address of the person for which the F/B list should be
-              retrieved
-        @param start Start of the period to get F/B data for
-        @param end End of the period to get F/B data for
-        @return true if a free-busy provider has been contacted, regardless
-                of the fact that it will respond positively to the handling
-                request
-      */
-    bool retrieveFreeBusy(const QString &email, const KDateTime &start,
-                          const KDateTime &end);
+                          QWidget *parentWidget = nullptr);
 
     /**
       Clears the retrieval queue, i.e. all retrieval request that are not started
@@ -132,7 +115,7 @@ public:
       @param email is a QString containing a email string in the
       "FirstName LastName <emailaddress>" format.
     */
-    KCalCore::FreeBusy::Ptr loadFreeBusy(const QString &email) Q_DECL_OVERRIDE;
+    KCalCore::FreeBusy::Ptr loadFreeBusy(const QString &email) override;
 
     /**
       Save freebusy information belonging to an email.
@@ -143,7 +126,7 @@ public:
       @param person is a valid Person instance.
     */
     bool saveFreeBusy(const KCalCore::FreeBusy::Ptr &freebusy,
-                      const KCalCore::Person::Ptr &person) Q_DECL_OVERRIDE;
+                      const KCalCore::Person::Ptr &person) override;
 
 Q_SIGNALS:
     /**
@@ -154,7 +137,7 @@ Q_SIGNALS:
 
 protected:
     /** React on timer events, used for delayed freebusy list uploading */
-    void timerEvent(QTimerEvent *event) Q_DECL_OVERRIDE;
+    void timerEvent(QTimerEvent *event) override;
 
 private:
     /**
