@@ -346,6 +346,7 @@ void ITIPHandler::publishInformation(const KCalCore::Incidence::Ptr &incidence,
     if (publishdlg->exec() == QDialog::Accepted && publishdlg) {
         d->m_scheduler->publish(incidence, publishdlg->addresses());
     } else {
+        d->m_currentOperation = OperationNone;
         emit informationPublished(ResultSuccess, QString());    // Canceled.
     }
     delete publishdlg;
@@ -377,7 +378,7 @@ void ITIPHandler::sendAsICalendar(const KCalCore::Incidence::Ptr &originalIncide
 
         if (incidence->hasRecurrenceId()) {
             // For an individual occurrence, recur id doesn't make sense, since we're not sending the whole recurrence series.
-            incidence->setRecurrenceId(KDateTime());
+            incidence->setRecurrenceId({});
         }
 
         KCalCore::ICalFormat format;
@@ -386,8 +387,7 @@ void ITIPHandler::sendAsICalendar(const KCalCore::Incidence::Ptr &originalIncide
         const QString messageText = format.createScheduleMessage(incidence, KCalCore::iTIPRequest);
         MailClient *mailer = new MailClient(d->m_factory);
         d->m_queuedInvitation.incidence = incidence;
-        connect(mailer, SIGNAL(finished(Akonadi::MailClient::Result,QString)),
-                d, SLOT(finishSendAsICalendar(Akonadi::MailScheduler::Result,QString)));
+        connect(mailer, &MailClient::finished, d, [this](Akonadi::MailClient::Result result, const QString &str) { d->finishSendAsICalendar(result,str); });
 
         mailer->mailTo(incidence, KIdentityManagement::IdentityManager::self()->identityForAddress(from), from, bccMe,
                        recipients, messageText,
@@ -417,4 +417,3 @@ Akonadi::CalendarBase::Ptr ITIPHandler::calendar() const
 {
     return d->m_calendar;
 }
-
