@@ -73,21 +73,21 @@ public:
     bool isLoaded(); // don't make const
 
     Invitation m_queuedInvitation;
-    bool m_calendarLoadError;
+    bool m_calendarLoadError = false;
     CalendarBase::Ptr m_calendar;
-    ITIPHandlerComponentFactory *m_factory;
-    MailScheduler *m_scheduler;
+    ITIPHandlerComponentFactory *m_factory = nullptr;
+    MailScheduler *m_scheduler = nullptr;
     KCalCore::Incidence::Ptr m_incidence;
     KCalCore::iTIPMethod m_method; // METHOD field of ical rfc of incoming invitation
-    ITIPHandlerHelper *m_helper;
+    ITIPHandlerHelper *m_helper = nullptr;
     Operation m_currentOperation;
     QPointer<QWidget> m_parentWidget; // To be used for KMessageBoxes
-    GroupwareUiDelegate *m_uiDelegate;
-    bool m_showDialogsOnError;
+    GroupwareUiDelegate *m_uiDelegate = nullptr;
+    bool m_showDialogsOnError = true;
     ITIPHandler *const q;
 
-private Q_SLOTS:
-    void finishSendAsICalendar(Akonadi::MailScheduler::Result, const QString &errorMessage);
+    void finishSendAsICalendar(Akonadi::MailClient::Result, const QString &errorMessage);
+private:
     void onLoadFinished(bool success, const QString &errorMessage);
     void onSchedulerFinished(Akonadi::Scheduler::Result, const QString &errorMessage);
     void onHelperFinished(Akonadi::ITIPHandlerHelper::SendResult result,
