@@ -41,7 +41,6 @@
 #include <KLocalizedString>
 #include <KJob>
 #include <KProtocolManager>
-#include <KSystemTimeZone>
 
 using namespace Akonadi;
 
@@ -91,9 +90,9 @@ void MailClient::mailAttendees(const KCalCore::IncidenceBase::Ptr &incidence,
         // Optional Participants and Non-Participants are copied on the email
         if (a->role() == KCalCore::Attendee::OptParticipant ||
                 a->role() == KCalCore::Attendee::NonParticipant) {
-            ccList << a->fullName();
+            ccList << a->email();
         } else {
-            toList << a->fullName();
+            toList << a->email();
         }
     }
     if (toList.isEmpty() && ccList.isEmpty()) {
@@ -119,8 +118,7 @@ void MailClient::mailAttendees(const KCalCore::IncidenceBase::Ptr &incidence,
         subject = i18n("Free Busy Object");
     }
 
-    const QString body = KCalUtils::IncidenceFormatter::mailBodyStr(incidence,
-                         KSystemTimeZones::local());
+    const QString body = KCalUtils::IncidenceFormatter::mailBodyStr(incidence);
 
     send(incidence, identity, from, to, cc, subject, body, false, bccMe, attachment, mailTransport);
 }
@@ -143,8 +141,7 @@ void MailClient::mailOrganizer(const KCalCore::IncidenceBase::Ptr &incidence,
         subject = i18n("Free Busy Message");
     }
 
-    const QString body = KCalUtils::IncidenceFormatter::mailBodyStr(incidence,
-                         KSystemTimeZones::local());
+    const QString body = KCalUtils::IncidenceFormatter::mailBodyStr(incidence);
 
     send(incidence, identity, from, to, QString(), subject, body, false, bccMe, attachment, mailTransport);
 }
@@ -164,8 +161,7 @@ void MailClient::mailTo(const KCalCore::IncidenceBase::Ptr &incidence,
         subject = i18n("Free Busy Message");
     }
 
-    const QString body = KCalUtils::IncidenceFormatter::mailBodyStr(incidence,
-                         KSystemTimeZones::local());
+    const QString body = KCalUtils::IncidenceFormatter::mailBodyStr(incidence);
 
     send(incidence, identity, from, recipients, QString(), subject, body, false,
          bccMe, attachment, mailTransport);
@@ -204,8 +200,6 @@ void MailClient::send(const KCalCore::IncidenceBase::Ptr &incidence,
     if (to.isEmpty()) {
         to = from;
     }
-    to = KEmailAddress::extractEmailAddress(
-                                       KEmailAddress::normalizeAddressesAndEncodeIdn(to));
     qCDebug(AKONADICALENDAR_LOG) << "\nFrom:" << from
                                  << "\nTo:" << to
                                  << "\nCC:" << cc
